@@ -9,10 +9,11 @@
 """
 
 import platform
+import sys
 
 import pytest
 
-from test_autodoc import do_autodoc
+from test_ext_autodoc import do_autodoc
 
 IS_PYPY = platform.python_implementation() == 'PyPy'
 
@@ -27,7 +28,7 @@ def test_autoclass_content_class(app):
         '.. py:module:: target.autoclass_content',
         '',
         '',
-        '.. py:class:: A',
+        '.. py:class:: A()',
         '   :module: target.autoclass_content',
         '',
         '   A class having no __init__, no __new__',
@@ -45,13 +46,13 @@ def test_autoclass_content_class(app):
         '   A class having __init__, no __new__',
         '',
         '',
-        '.. py:class:: D',
+        '.. py:class:: D()',
         '   :module: target.autoclass_content',
         '',
         '   A class having no __init__, __new__(no docstring)',
         '',
         '',
-        '.. py:class:: E',
+        '.. py:class:: E()',
         '   :module: target.autoclass_content',
         '',
         '   A class having no __init__, __new__',
@@ -87,7 +88,7 @@ def test_autoclass_content_init(app):
         '.. py:module:: target.autoclass_content',
         '',
         '',
-        '.. py:class:: A',
+        '.. py:class:: A()',
         '   :module: target.autoclass_content',
         '',
         '   A class having no __init__, no __new__',
@@ -105,13 +106,13 @@ def test_autoclass_content_init(app):
         '   __init__ docstring',
         '',
         '',
-        '.. py:class:: D',
+        '.. py:class:: D()',
         '   :module: target.autoclass_content',
         '',
         '   A class having no __init__, __new__(no docstring)',
         '',
         '',
-        '.. py:class:: E',
+        '.. py:class:: E()',
         '   :module: target.autoclass_content',
         '',
         '   __new__ docstring',
@@ -147,7 +148,7 @@ def test_autoclass_content_both(app):
         '.. py:module:: target.autoclass_content',
         '',
         '',
-        '.. py:class:: A',
+        '.. py:class:: A()',
         '   :module: target.autoclass_content',
         '',
         '   A class having no __init__, no __new__',
@@ -167,13 +168,13 @@ def test_autoclass_content_both(app):
         '   __init__ docstring',
         '',
         '',
-        '.. py:class:: D',
+        '.. py:class:: D()',
         '   :module: target.autoclass_content',
         '',
         '   A class having no __init__, __new__(no docstring)',
         '',
         '',
-        '.. py:class:: E',
+        '.. py:class:: E()',
         '   :module: target.autoclass_content',
         '',
         '   A class having no __init__, __new__',
@@ -237,7 +238,7 @@ def test_autodoc_docstring_signature(app):
     actual = do_autodoc(app, 'class', 'target.DocstringSig', options)
     assert list(actual) == [
         '',
-        '.. py:class:: DocstringSig',
+        '.. py:class:: DocstringSig()',
         '   :module: target',
         '',
         '',
@@ -279,7 +280,7 @@ def test_autodoc_docstring_signature(app):
     actual = do_autodoc(app, 'class', 'target.DocstringSig', options)
     assert list(actual) == [
         '',
-        '.. py:class:: DocstringSig',
+        '.. py:class:: DocstringSig()',
         '   :module: target',
         '',
         '',
@@ -345,6 +346,10 @@ def test_autoclass_content_and_docstring_signature_class(app):
         '',
         '.. py:class:: D()',
         '   :module: target.docstring_signature',
+        '',
+        '',
+        '.. py:class:: E()',
+        '   :module: target.docstring_signature',
         ''
     ]
 
@@ -374,6 +379,11 @@ def test_autoclass_content_and_docstring_signature_init(app):
         '',
         '.. py:class:: D(foo, bar, baz)',
         '   :module: target.docstring_signature',
+        '',
+        '',
+        '.. py:class:: E(foo: int, bar: int, baz: int) -> None',
+        '              E(foo: str, bar: str, baz: str) -> None',
+        '   :module: target.docstring_signature',
         ''
     ]
 
@@ -408,6 +418,11 @@ def test_autoclass_content_and_docstring_signature_both(app):
         '.. py:class:: D(foo, bar, baz)',
         '   :module: target.docstring_signature',
         '',
+        '',
+        '.. py:class:: E(foo: int, bar: int, baz: int) -> None',
+        '              E(foo: str, bar: str, baz: str) -> None',
+        '   :module: target.docstring_signature',
+        '',
     ]
 
 
@@ -435,7 +450,7 @@ def test_mocked_module_imports(app, warning):
         '.. py:module:: target.need_mocks',
         '',
         '',
-        '.. py:class:: TestAutodoc',
+        '.. py:class:: TestAutodoc()',
         '   :module: target.need_mocks',
         '',
         '   TestAutodoc docstring.',
@@ -493,6 +508,18 @@ def test_autodoc_typehints_signature(app):
         '      :module: target.typehints',
         '',
         '',
+        '.. py:class:: NewAnnotation(i: int)',
+        '   :module: target.typehints',
+        '',
+        '',
+        '.. py:class:: NewComment(i: int)',
+        '   :module: target.typehints',
+        '',
+        '',
+        '.. py:class:: SignatureFromMetaclass(a: int)',
+        '   :module: target.typehints',
+        '',
+        '',
         '.. py:function:: complex_func(arg1: str, arg2: List[int], arg3: Tuple[int, '
         'Union[str, Unknown]] = None, *args: str, **kwargs: str) -> None',
         '   :module: target.typehints',
@@ -508,7 +535,11 @@ def test_autodoc_typehints_signature(app):
         '',
         '.. py:function:: missing_attr(c, a: str, b: Optional[str] = None) -> str',
         '   :module: target.typehints',
-        ''
+        '',
+        '',
+        '.. py:function:: tuple_args(x: Tuple[int, Union[int, str]]) -> Tuple[int, int]',
+        '   :module: target.typehints',
+        '',
     ]
 
 
@@ -543,6 +574,18 @@ def test_autodoc_typehints_none(app):
         '      :module: target.typehints',
         '',
         '',
+        '.. py:class:: NewAnnotation(i)',
+        '   :module: target.typehints',
+        '',
+        '',
+        '.. py:class:: NewComment(i)',
+        '   :module: target.typehints',
+        '',
+        '',
+        '.. py:class:: SignatureFromMetaclass(a)',
+        '   :module: target.typehints',
+        '',
+        '',
         '.. py:function:: complex_func(arg1, arg2, arg3=None, *args, **kwargs)',
         '   :module: target.typehints',
         '',
@@ -557,7 +600,11 @@ def test_autodoc_typehints_none(app):
         '',
         '.. py:function:: missing_attr(c, a, b=None)',
         '   :module: target.typehints',
-        ''
+        '',
+        '',
+        '.. py:function:: tuple_args(x)',
+        '   :module: target.typehints',
+        '',
     ]
 
 
@@ -576,6 +623,15 @@ def test_autodoc_typehints_description(app):
             '   Return type:\n'
             '      int\n'
             in context)
+    assert ('target.typehints.tuple_args(x)\n'
+            '\n'
+            '   Parameters:\n'
+            '      **x** (*Tuple**[**int**, **Union**[**int**, **str**]**]*) --\n'
+            '\n'
+            '   Return type:\n'
+            '      Tuple[int, int]\n'
+            in context)
+
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
